
################################################################
# This is a generated script based on design: zed
#
# Though there are limitations about the generated script,
# the main purpose of this utility is to make learning
# IP Integrator Tcl commands easier.
################################################################

################################################################
# Check if script is running in correct Vivado version.
################################################################
set scripts_vivado_version 2015.4
set current_vivado_version [version -short]

if { [string first $scripts_vivado_version $current_vivado_version] == -1 } {
   puts ""
   puts "ERROR: This script was generated using Vivado <$scripts_vivado_version> and is being run in <$current_vivado_version> of Vivado. Please run the script in Vivado <$scripts_vivado_version> then open the design in Vivado <$current_vivado_version>. Upgrade the design by running \"Tools => Report => Report IP Status...\", then run write_bd_tcl to create an updated script."

   return 1
}

################################################################
# START
################################################################

# To test this script, run the following commands from Vivado Tcl console:
# source zed_script.tcl

# If you do not already have a project created,
# you can create a project using the following command:
#    create_project project_1 myproj -part xc7z015clg485-1

# CHECKING IF PROJECT EXISTS
if { [get_projects -quiet] eq "" } {
   puts "ERROR: Please open or create a project!"
   return 1
}



# CHANGE DESIGN NAME HERE
set design_name zed

# If you do not already have an existing IP Integrator design open,
# you can create a design using the following command:
#    create_bd_design $design_name

# Creating design if needed
set errMsg ""
set nRet 0

set cur_design [current_bd_design -quiet]
set list_cells [get_bd_cells -quiet]

if { ${design_name} eq "" } {
   # USE CASES:
   #    1) Design_name not set

   set errMsg "ERROR: Please set the variable <design_name> to a non-empty value."
   set nRet 1

} elseif { ${cur_design} ne "" && ${list_cells} eq "" } {
   # USE CASES:
   #    2): Current design opened AND is empty AND names same.
   #    3): Current design opened AND is empty AND names diff; design_name NOT in project.
   #    4): Current design opened AND is empty AND names diff; design_name exists in project.

   if { $cur_design ne $design_name } {
      puts "INFO: Changing value of <design_name> from <$design_name> to <$cur_design> since current design is empty."
      set design_name [get_property NAME $cur_design]
   }
   puts "INFO: Constructing design in IPI design <$cur_design>..."

} elseif { ${cur_design} ne "" && $list_cells ne "" && $cur_design eq $design_name } {
   # USE CASES:
   #    5) Current design opened AND has components AND same names.

   set errMsg "ERROR: Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 1
} elseif { [get_files -quiet ${design_name}.bd] ne "" } {
   # USE CASES: 
   #    6) Current opened design, has components, but diff names, design_name exists in project.
   #    7) No opened design, design_name exists in project.

   set errMsg "ERROR: Design <$design_name> already exists in your project, please set the variable <design_name> to another value."
   set nRet 2

} else {
   # USE CASES:
   #    8) No opened design, design_name not in project.
   #    9) Current opened design, has components, but diff names, design_name not in project.

   puts "INFO: Currently there is no design <$design_name> in project, so creating one..."

   create_bd_design $design_name

   puts "INFO: Making design <$design_name> as current_bd_design."
   current_bd_design $design_name

}

puts "INFO: Currently the variable <design_name> is equal to \"$design_name\"."

if { $nRet != 0 } {
   puts $errMsg
   return $nRet
}

##################################################################
# DESIGN PROCs
##################################################################



# Procedure to create entire design; Provide argument to make
# procedure reusable. If parentCell is "", will use root.
proc create_root_design { parentCell } {

  if { $parentCell eq "" } {
     set parentCell [get_bd_cells /]
  }

  # Get object for parentCell
  set parentObj [get_bd_cells $parentCell]
  if { $parentObj == "" } {
     puts "ERROR: Unable to find parent cell <$parentCell>!"
     return
  }

  # Make sure parentObj is hier blk
  set parentType [get_property TYPE $parentObj]
  if { $parentType ne "hier" } {
     puts "ERROR: Parent <$parentObj> has TYPE = <$parentType>. Expected to be <hier>."
     return
  }

  # Save current instance; Restore later
  set oldCurInst [current_bd_instance .]

  # Set parent object as current
  current_bd_instance $parentObj


  # Create interface ports
  set DDR [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:ddrx_rtl:1.0 DDR ]
  set FIXED_IO [ create_bd_intf_port -mode Master -vlnv xilinx.com:display_processing_system7:fixedio_rtl:1.0 FIXED_IO ]
  set GPIO_0 [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:gpio_rtl:1.0 GPIO_0 ]
  set M_AHB [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:ahblite_rtl:2.0 M_AHB ]
  set S_AXI_HP3 [ create_bd_intf_port -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 S_AXI_HP3 ]
  set_property -dict [ list \
CONFIG.ADDR_WIDTH {32} \
CONFIG.ARUSER_WIDTH {0} \
CONFIG.AWUSER_WIDTH {0} \
CONFIG.BUSER_WIDTH {0} \
CONFIG.DATA_WIDTH {64} \
CONFIG.HAS_BRESP {1} \
CONFIG.HAS_BURST {1} \
CONFIG.HAS_CACHE {1} \
CONFIG.HAS_LOCK {1} \
CONFIG.HAS_PROT {1} \
CONFIG.HAS_QOS {1} \
CONFIG.HAS_REGION {1} \
CONFIG.HAS_RRESP {1} \
CONFIG.HAS_WSTRB {1} \
CONFIG.ID_WIDTH {6} \
CONFIG.MAX_BURST_LENGTH {16} \
CONFIG.NUM_READ_OUTSTANDING {8} \
CONFIG.NUM_WRITE_OUTSTANDING {8} \
CONFIG.PHASE {0.000} \
CONFIG.PROTOCOL {AXI3} \
CONFIG.READ_WRITE_MODE {READ_WRITE} \
CONFIG.RUSER_WIDTH {0} \
CONFIG.SUPPORTS_NARROW_BURST {1} \
CONFIG.WUSER_WIDTH {0} \
 ] $S_AXI_HP3
  set TGIGE0_BRAM_PORTA_0 [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:bram_rtl:1.0 TGIGE0_BRAM_PORTA_0 ]
  set_property -dict [ list \
CONFIG.MASTER_TYPE {BRAM_CTRL} \
 ] $TGIGE0_BRAM_PORTA_0
  set TGIGE0_BRAM_PORTA_1 [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:bram_rtl:1.0 TGIGE0_BRAM_PORTA_1 ]
  set_property -dict [ list \
CONFIG.MASTER_TYPE {BRAM_CTRL} \
 ] $TGIGE0_BRAM_PORTA_1
  set TGIGE0_BRAM_PORTA_2 [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:bram_rtl:1.0 TGIGE0_BRAM_PORTA_2 ]
  set_property -dict [ list \
CONFIG.MASTER_TYPE {BRAM_CTRL} \
 ] $TGIGE0_BRAM_PORTA_2
  set TGIGE0_BRAM_PORTA_3 [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:bram_rtl:1.0 TGIGE0_BRAM_PORTA_3 ]
  set_property -dict [ list \
CONFIG.MASTER_TYPE {BRAM_CTRL} \
 ] $TGIGE0_BRAM_PORTA_3
  set TGIGE0_BRAM_PORTA_4 [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:bram_rtl:1.0 TGIGE0_BRAM_PORTA_4 ]
  set_property -dict [ list \
CONFIG.MASTER_TYPE {BRAM_CTRL} \
 ] $TGIGE0_BRAM_PORTA_4
  set TGIGE0_BRAM_PORTA_5 [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:bram_rtl:1.0 TGIGE0_BRAM_PORTA_5 ]
  set_property -dict [ list \
CONFIG.MASTER_TYPE {BRAM_CTRL} \
 ] $TGIGE0_BRAM_PORTA_5
  set TGIGE0_DDR_RW [ create_bd_intf_port -mode Slave -vlnv xilinx.com:interface:aximm_rtl:1.0 TGIGE0_DDR_RW ]
  set_property -dict [ list \
CONFIG.ADDR_WIDTH {32} \
CONFIG.ARUSER_WIDTH {0} \
CONFIG.AWUSER_WIDTH {0} \
CONFIG.BUSER_WIDTH {0} \
CONFIG.DATA_WIDTH {128} \
CONFIG.FREQ_HZ {74250000} \
CONFIG.HAS_BRESP {1} \
CONFIG.HAS_BURST {1} \
CONFIG.HAS_CACHE {1} \
CONFIG.HAS_LOCK {1} \
CONFIG.HAS_PROT {1} \
CONFIG.HAS_QOS {1} \
CONFIG.HAS_REGION {1} \
CONFIG.HAS_RRESP {1} \
CONFIG.HAS_WSTRB {1} \
CONFIG.ID_WIDTH {5} \
CONFIG.MAX_BURST_LENGTH {256} \
CONFIG.NUM_READ_OUTSTANDING {2} \
CONFIG.NUM_WRITE_OUTSTANDING {2} \
CONFIG.PROTOCOL {AXI4} \
CONFIG.READ_WRITE_MODE {READ_WRITE} \
CONFIG.RUSER_WIDTH {0} \
CONFIG.SUPPORTS_NARROW_BURST {1} \
CONFIG.WUSER_WIDTH {0} \
 ] $TGIGE0_DDR_RW
  set axi4lite_ext_slave_conn_0 [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:aximm_rtl:1.0 axi4lite_ext_slave_conn_0 ]
  set_property -dict [ list \
CONFIG.ADDR_WIDTH {32} \
CONFIG.DATA_WIDTH {32} \
CONFIG.NUM_READ_OUTSTANDING {2} \
CONFIG.NUM_WRITE_OUTSTANDING {2} \
CONFIG.PROTOCOL {AXI4LITE} \
 ] $axi4lite_ext_slave_conn_0
  set logicvc_0_vid_io [ create_bd_intf_port -mode Master -vlnv xilinx.com:interface:vid_io_rtl:1.0 logicvc_0_vid_io ]

  # Create ports
  set CLK_100M [ create_bd_port -dir O -type clk CLK_100M ]
  set_property -dict [ list \
CONFIG.ASSOCIATED_BUSIF {axi4lite_ext_slave_conn_0} \
 ] $CLK_100M
  set CLK_125M [ create_bd_port -dir O -type clk CLK_125M ]
  set CLK_200M [ create_bd_port -dir O -type clk CLK_200M ]
  set CLK_25M [ create_bd_port -dir O -type clk CLK_25M ]
  set CLOCK_160MHz [ create_bd_port -dir O -type clk CLOCK_160MHz ]
  set_property -dict [ list \
CONFIG.ASSOCIATED_BUSIF {S_AXI_HP3} \
 ] $CLOCK_160MHz
  set FCLK_RESET1_N [ create_bd_port -dir O -type rst FCLK_RESET1_N ]
  set MB_Reset [ create_bd_port -dir I -type rst MB_Reset ]
  set_property -dict [ list \
CONFIG.POLARITY {ACTIVE_HIGH} \
 ] $MB_Reset
  set TGIGE0_rx_icmp_int [ create_bd_port -dir I -from 0 -to 0 TGIGE0_rx_icmp_int ]
  set TGIGE0_rx_norm_int [ create_bd_port -dir I -from 0 -to 0 TGIGE0_rx_norm_int ]
  set TGIGE0_tx_gvcp_int [ create_bd_port -dir I -from 0 -to 0 TGIGE0_tx_gvcp_int ]
  set TGIGE0_tx_gvsp_int [ create_bd_port -dir I -from 0 -to 0 TGIGE0_tx_gvsp_int ]
  set TGIGE0_tx_nonmac_int [ create_bd_port -dir I -from 0 -to 0 TGIGE0_tx_nonmac_int ]
  set TGIGE0_tx_retr_int [ create_bd_port -dir I -from 0 -to 0 TGIGE0_tx_retr_int ]
  set hdmi_in_2_data [ create_bd_port -dir I -from 23 -to 0 hdmi_in_2_data ]
  set hdmi_in_2_vclk [ create_bd_port -dir I hdmi_in_2_vclk ]
  set logicvc_0_pix_clk [ create_bd_port -dir O logicvc_0_pix_clk ]
  set vdata_in_de_0 [ create_bd_port -dir I vdata_in_de_0 ]
  set vdata_in_fld_0 [ create_bd_port -dir I vdata_in_fld_0 ]
  set vdata_in_hs_0 [ create_bd_port -dir I vdata_in_hs_0 ]
  set vdata_in_vs_0 [ create_bd_port -dir I vdata_in_vs_0 ]
  set video_clk [ create_bd_port -dir I -type clk video_clk ]
  set_property -dict [ list \
CONFIG.ASSOCIATED_BUSIF {TGIGE0_DDR_RW} \
CONFIG.FREQ_HZ {74250000} \
 ] $video_clk

  # Create instance: axi4_lite, and set properties
  set axi4_lite [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 axi4_lite ]
  set_property -dict [ list \
CONFIG.NUM_MI {3} \
CONFIG.NUM_SI {1} \
 ] $axi4_lite

  # Create instance: axi_ahblite_bridge_0, and set properties
  set axi_ahblite_bridge_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_ahblite_bridge:3.0 axi_ahblite_bridge_0 ]

  # Create instance: axi_bram_ctrl_0, and set properties
  set axi_bram_ctrl_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_bram_ctrl:4.0 axi_bram_ctrl_0 ]
  set_property -dict [ list \
CONFIG.ECC_TYPE {0} \
CONFIG.PROTOCOL {AXI4LITE} \
CONFIG.SINGLE_PORT_BRAM {1} \
 ] $axi_bram_ctrl_0

  # Create instance: axi_bram_ctrl_1, and set properties
  set axi_bram_ctrl_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_bram_ctrl:4.0 axi_bram_ctrl_1 ]
  set_property -dict [ list \
CONFIG.ECC_TYPE {0} \
CONFIG.PROTOCOL {AXI4LITE} \
CONFIG.SINGLE_PORT_BRAM {1} \
 ] $axi_bram_ctrl_1

  # Create instance: axi_bram_ctrl_2, and set properties
  set axi_bram_ctrl_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_bram_ctrl:4.0 axi_bram_ctrl_2 ]
  set_property -dict [ list \
CONFIG.ECC_TYPE {0} \
CONFIG.PROTOCOL {AXI4LITE} \
CONFIG.SINGLE_PORT_BRAM {1} \
 ] $axi_bram_ctrl_2

  # Create instance: axi_bram_ctrl_3, and set properties
  set axi_bram_ctrl_3 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_bram_ctrl:4.0 axi_bram_ctrl_3 ]
  set_property -dict [ list \
CONFIG.ECC_TYPE {0} \
CONFIG.PROTOCOL {AXI4LITE} \
CONFIG.SINGLE_PORT_BRAM {1} \
 ] $axi_bram_ctrl_3

  # Create instance: axi_bram_ctrl_4, and set properties
  set axi_bram_ctrl_4 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_bram_ctrl:4.0 axi_bram_ctrl_4 ]
  set_property -dict [ list \
CONFIG.ECC_TYPE {0} \
CONFIG.PROTOCOL {AXI4LITE} \
CONFIG.SINGLE_PORT_BRAM {1} \
 ] $axi_bram_ctrl_4

  # Create instance: axi_bram_ctrl_5, and set properties
  set axi_bram_ctrl_5 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_bram_ctrl:4.0 axi_bram_ctrl_5 ]
  set_property -dict [ list \
CONFIG.ECC_TYPE {0} \
CONFIG.PROTOCOL {AXI4LITE} \
CONFIG.SINGLE_PORT_BRAM {1} \
 ] $axi_bram_ctrl_5

  # Create instance: axi_clock_converter_0, and set properties
  set axi_clock_converter_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_clock_converter:2.1 axi_clock_converter_0 ]

  # Create instance: axi_clock_converter_1, and set properties
  set axi_clock_converter_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_clock_converter:2.1 axi_clock_converter_1 ]

  # Create instance: axi_clock_converter_3, and set properties
  set axi_clock_converter_3 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_clock_converter:2.1 axi_clock_converter_3 ]

  # Create instance: axi_intc_0, and set properties
  set axi_intc_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_intc:4.1 axi_intc_0 ]
  set_property -dict [ list \
CONFIG.C_KIND_OF_EDGE {0xFFFFFFFF} \
CONFIG.C_KIND_OF_INTR {0x00000000} \
CONFIG.C_KIND_OF_LVL {0xFFFFFFFF} \
CONFIG.C_S_AXI_ACLK_FREQ_MHZ {160.0} \
 ] $axi_intc_0

  # Create instance: axi_interconnect_0, and set properties
  set axi_interconnect_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 axi_interconnect_0 ]
  set_property -dict [ list \
CONFIG.M00_HAS_DATA_FIFO {2} \
CONFIG.NUM_MI {1} \
CONFIG.NUM_SI {4} \
CONFIG.S02_HAS_DATA_FIFO {2} \
CONFIG.S03_HAS_DATA_FIFO {2} \
 ] $axi_interconnect_0

  # Create instance: axi_interconnect_2, and set properties
  set axi_interconnect_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 axi_interconnect_2 ]
  set_property -dict [ list \
CONFIG.NUM_MI {1} \
CONFIG.NUM_SI {1} \
 ] $axi_interconnect_2

  # Create instance: axi_interconnect_4, and set properties
  set axi_interconnect_4 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_interconnect:2.1 axi_interconnect_4 ]
  set_property -dict [ list \
CONFIG.NUM_MI {9} \
 ] $axi_interconnect_4

  # Create instance: axi_timer_0, and set properties
  set axi_timer_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_timer:2.0 axi_timer_0 ]

  # Create instance: blk_mem_gen_0, and set properties
  set blk_mem_gen_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:blk_mem_gen:8.3 blk_mem_gen_0 ]
  set_property -dict [ list \
CONFIG.Enable_B {Use_ENB_Pin} \
CONFIG.Memory_Type {True_Dual_Port_RAM} \
CONFIG.Port_B_Clock {100} \
CONFIG.Port_B_Enable_Rate {100} \
CONFIG.Port_B_Write_Rate {50} \
CONFIG.Use_RSTB_Pin {true} \
 ] $blk_mem_gen_0

  # Create instance: clk1_reset, and set properties
  set clk1_reset [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 clk1_reset ]

  # Create instance: clk2_reset, and set properties
  set clk2_reset [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 clk2_reset ]

  # Create instance: clk_wiz_0, and set properties
  set clk_wiz_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:clk_wiz:5.2 clk_wiz_0 ]
  set_property -dict [ list \
CONFIG.CLKOUT1_JITTER {209.704} \
CONFIG.CLKOUT1_PHASE_ERROR {300.991} \
CONFIG.CLKOUT1_REQUESTED_OUT_FREQ {160.000} \
CONFIG.CLKOUT2_JITTER {275.906} \
CONFIG.CLKOUT2_PHASE_ERROR {300.991} \
CONFIG.CLKOUT2_REQUESTED_OUT_FREQ {27.000} \
CONFIG.CLKOUT2_USED {true} \
CONFIG.CLKOUT3_JITTER {191.696} \
CONFIG.CLKOUT3_PHASE_ERROR {114.212} \
CONFIG.CLKOUT3_REQUESTED_OUT_FREQ {100.000} \
CONFIG.CLKOUT3_USED {false} \
CONFIG.CLKOUT4_JITTER {129.475} \
CONFIG.CLKOUT4_PHASE_ERROR {157.116} \
CONFIG.CLKOUT4_USED {false} \
CONFIG.CLKOUT5_JITTER {130.874} \
CONFIG.CLKOUT5_PHASE_ERROR {157.116} \
CONFIG.MMCM_CLKFBOUT_MULT_F {54.000} \
CONFIG.MMCM_CLKOUT0_DIVIDE_F {6.750} \
CONFIG.MMCM_CLKOUT1_DIVIDE {40} \
CONFIG.MMCM_CLKOUT2_DIVIDE {1} \
CONFIG.MMCM_DIVCLK_DIVIDE {5} \
CONFIG.NUM_OUT_CLKS {2} \
CONFIG.PRIM_IN_FREQ {100.000} \
CONFIG.RESET_TYPE {ACTIVE_LOW} \
 ] $clk_wiz_0

  # Create instance: lmb_bram_if_cntlr_0, and set properties
  set lmb_bram_if_cntlr_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:lmb_bram_if_cntlr:4.0 lmb_bram_if_cntlr_0 ]

  # Create instance: lmb_bram_if_cntlr_1, and set properties
  set lmb_bram_if_cntlr_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:lmb_bram_if_cntlr:4.0 lmb_bram_if_cntlr_1 ]

  # Create instance: lmb_v10_0, and set properties
  set lmb_v10_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:lmb_v10:3.0 lmb_v10_0 ]

  # Create instance: lmb_v10_1, and set properties
  set lmb_v10_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:lmb_v10:3.0 lmb_v10_1 ]

  # Create instance: logicvc_0, and set properties
  set logicvc_0 [ create_bd_cell -type ip -vlnv logicbricks.com:logicbricks:logicvc:4.2 logicvc_0 ]
  set_property -dict [ list \
CONFIG.C_BUFFER_0_OFFSET {1080} \
CONFIG.C_BUFFER_1_OFFSET {1080} \
CONFIG.C_DISPLAY_COLOR_SPACE {1} \
CONFIG.C_LAYER_0_ADDR {0x32000000} \
CONFIG.C_LAYER_0_ALPHA_MODE {1} \
CONFIG.C_LAYER_0_DATA_WIDTH {24} \
CONFIG.C_LAYER_1_ADDR {0x34000000} \
CONFIG.C_LAYER_1_ALPHA_MODE {0} \
CONFIG.C_LAYER_1_DATA_WIDTH {16} \
CONFIG.C_LAYER_1_TYPE {1} \
CONFIG.C_MEM_BURST {6} \
CONFIG.C_NUM_OF_LAYERS {2} \
CONFIG.C_PIXEL_DATA_WIDTH {16} \
CONFIG.C_ROW_STRIDE {2048} \
CONFIG.C_USE_EXT_BUFFERING {1} \
CONFIG.C_USE_MULTIPLIER {1} \
 ] $logicvc_0

  # Create instance: logiwin_1, and set properties
  set logiwin_1 [ create_bd_cell -type ip -vlnv logicbricks.com:logicbricks:logiwin:4.2 logiwin_1 ]
  set_property -dict [ list \
CONFIG.C_BUFFER_OFFSET {1080} \
CONFIG.C_INPUT_0_TYPE {2} \
CONFIG.C_MAX_INPUT_RES {2048} \
CONFIG.C_MEM_BURST {6} \
CONFIG.C_OUTPUT_TYPE {4} \
CONFIG.C_USE_BUFG {0} \
CONFIG.C_YUV_LAYOUT {0} \
 ] $logiwin_1

  # Create instance: mdm_0, and set properties
  set mdm_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:mdm:3.2 mdm_0 ]

  # Create instance: microblaze_0, and set properties
  set microblaze_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:microblaze:9.5 microblaze_0 ]
  set_property -dict [ list \
CONFIG.C_CACHE_BYTE_SIZE {4096} \
CONFIG.C_DCACHE_BASEADDR {0x38000000} \
CONFIG.C_DCACHE_BYTE_SIZE {4096} \
CONFIG.C_DCACHE_HIGHADDR {0x3FFFFFFF} \
CONFIG.C_D_AXI {1} \
CONFIG.C_ICACHE_BASEADDR {0x38000000} \
CONFIG.C_ICACHE_HIGHADDR {0x3FFFFFFF} \
CONFIG.C_NUMBER_OF_PC_BRK {8} \
CONFIG.C_NUMBER_OF_RD_ADDR_BRK {4} \
CONFIG.C_NUMBER_OF_WR_ADDR_BRK {4} \
CONFIG.C_USE_BARREL {1} \
CONFIG.C_USE_DCACHE {1} \
CONFIG.C_USE_HW_MUL {1} \
CONFIG.C_USE_ICACHE {1} \
CONFIG.C_USE_MSR_INSTR {1} \
CONFIG.C_USE_PCMP_INSTR {1} \
 ] $microblaze_0

  # Create instance: oidsconcat_0, and set properties
  set oidsconcat_0 [ create_bd_cell -type ip -vlnv co.jp:user:oidsconcat:1.0 oidsconcat_0 ]
  set_property -dict [ list \
CONFIG.NUM_PORTS {2} \
 ] $oidsconcat_0

  # Create instance: oidsconcat_1, and set properties
  set oidsconcat_1 [ create_bd_cell -type ip -vlnv co.jp:user:oidsconcat:1.0 oidsconcat_1 ]
  set_property -dict [ list \
CONFIG.NUM_PORTS {4} \
 ] $oidsconcat_1

  # Create instance: proc_sys_reset_1, and set properties
  set proc_sys_reset_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:proc_sys_reset:5.0 proc_sys_reset_1 ]

  # Create instance: ps7, and set properties
  set ps7 [ create_bd_cell -type ip -vlnv xilinx.com:ip:processing_system7:5.5 ps7 ]
  set_property -dict [ list \
CONFIG.PCW_APU_PERIPHERAL_FREQMHZ {666.6667} \
CONFIG.PCW_CAN0_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_ENET0_ENET0_IO {MIO 16 .. 27} \
CONFIG.PCW_ENET0_GRP_MDIO_ENABLE {1} \
CONFIG.PCW_ENET0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_ENET0_PERIPHERAL_FREQMHZ {100 Mbps} \
CONFIG.PCW_ENET0_RESET_ENABLE {1} \
CONFIG.PCW_ENET0_RESET_IO {MIO 47} \
CONFIG.PCW_EN_CLK1_PORT {1} \
CONFIG.PCW_EN_CLK2_PORT {1} \
CONFIG.PCW_EN_CLK3_PORT {1} \
CONFIG.PCW_EN_RST1_PORT {1} \
CONFIG.PCW_FPGA0_PERIPHERAL_FREQMHZ {100} \
CONFIG.PCW_FPGA1_PERIPHERAL_FREQMHZ {166.666672} \
CONFIG.PCW_FPGA2_PERIPHERAL_FREQMHZ {125} \
CONFIG.PCW_FPGA3_PERIPHERAL_FREQMHZ {200} \
CONFIG.PCW_GPIO_EMIO_GPIO_ENABLE {1} \
CONFIG.PCW_GPIO_EMIO_GPIO_IO {8} \
CONFIG.PCW_GPIO_MIO_GPIO_ENABLE {1} \
CONFIG.PCW_I2C0_I2C0_IO {MIO 50 .. 51} \
CONFIG.PCW_I2C0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_I2C0_RESET_ENABLE {0} \
CONFIG.PCW_I2C0_RESET_IO {<Select>} \
CONFIG.PCW_I2C1_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_I2C_RESET_ENABLE {1} \
CONFIG.PCW_IMPORT_BOARD_PRESET {C:/USER/le785/DENSO/ps7_system_prj.xml} \
CONFIG.PCW_IRQ_F2P_INTR {1} \
CONFIG.PCW_MIO_10_PULLUP {disabled} \
CONFIG.PCW_MIO_11_PULLUP {disabled} \
CONFIG.PCW_MIO_12_PULLUP {disabled} \
CONFIG.PCW_MIO_13_PULLUP {disabled} \
CONFIG.PCW_MIO_14_PULLUP {disabled} \
CONFIG.PCW_MIO_15_PULLUP {disabled} \
CONFIG.PCW_MIO_16_IOTYPE {HSTL 1.8V} \
CONFIG.PCW_MIO_16_PULLUP {disabled} \
CONFIG.PCW_MIO_17_IOTYPE {HSTL 1.8V} \
CONFIG.PCW_MIO_17_PULLUP {disabled} \
CONFIG.PCW_MIO_18_IOTYPE {HSTL 1.8V} \
CONFIG.PCW_MIO_18_PULLUP {disabled} \
CONFIG.PCW_MIO_19_IOTYPE {HSTL 1.8V} \
CONFIG.PCW_MIO_19_PULLUP {disabled} \
CONFIG.PCW_MIO_1_PULLUP {enabled} \
CONFIG.PCW_MIO_20_IOTYPE {HSTL 1.8V} \
CONFIG.PCW_MIO_20_PULLUP {disabled} \
CONFIG.PCW_MIO_21_IOTYPE {HSTL 1.8V} \
CONFIG.PCW_MIO_21_PULLUP {disabled} \
CONFIG.PCW_MIO_22_IOTYPE {HSTL 1.8V} \
CONFIG.PCW_MIO_22_PULLUP {disabled} \
CONFIG.PCW_MIO_23_IOTYPE {HSTL 1.8V} \
CONFIG.PCW_MIO_23_PULLUP {disabled} \
CONFIG.PCW_MIO_24_IOTYPE {HSTL 1.8V} \
CONFIG.PCW_MIO_24_PULLUP {disabled} \
CONFIG.PCW_MIO_25_IOTYPE {HSTL 1.8V} \
CONFIG.PCW_MIO_25_PULLUP {disabled} \
CONFIG.PCW_MIO_26_IOTYPE {HSTL 1.8V} \
CONFIG.PCW_MIO_26_PULLUP {disabled} \
CONFIG.PCW_MIO_27_IOTYPE {HSTL 1.8V} \
CONFIG.PCW_MIO_27_PULLUP {disabled} \
CONFIG.PCW_MIO_28_PULLUP {disabled} \
CONFIG.PCW_MIO_29_PULLUP {disabled} \
CONFIG.PCW_MIO_30_PULLUP {disabled} \
CONFIG.PCW_MIO_31_PULLUP {disabled} \
CONFIG.PCW_MIO_32_PULLUP {disabled} \
CONFIG.PCW_MIO_33_PULLUP {disabled} \
CONFIG.PCW_MIO_34_PULLUP {disabled} \
CONFIG.PCW_MIO_35_PULLUP {disabled} \
CONFIG.PCW_MIO_36_PULLUP {disabled} \
CONFIG.PCW_MIO_37_PULLUP {disabled} \
CONFIG.PCW_MIO_38_PULLUP {disabled} \
CONFIG.PCW_MIO_39_PULLUP {disabled} \
CONFIG.PCW_MIO_40_PULLUP {disabled} \
CONFIG.PCW_MIO_41_PULLUP {disabled} \
CONFIG.PCW_MIO_42_PULLUP {disabled} \
CONFIG.PCW_MIO_43_PULLUP {disabled} \
CONFIG.PCW_MIO_44_PULLUP {disabled} \
CONFIG.PCW_MIO_45_PULLUP {disabled} \
CONFIG.PCW_MIO_48_PULLUP {disabled} \
CONFIG.PCW_MIO_49_PULLUP {disabled} \
CONFIG.PCW_MIO_50_PULLUP {disabled} \
CONFIG.PCW_MIO_51_PULLUP {disabled} \
CONFIG.PCW_MIO_52_PULLUP {disabled} \
CONFIG.PCW_MIO_53_PULLUP {disabled} \
CONFIG.PCW_PRESET_BANK0_VOLTAGE {LVCMOS 3.3V} \
CONFIG.PCW_PRESET_BANK1_VOLTAGE {LVCMOS 1.8V} \
CONFIG.PCW_QSPI_GRP_FBCLK_ENABLE {1} \
CONFIG.PCW_QSPI_GRP_IO1_ENABLE {0} \
CONFIG.PCW_QSPI_GRP_SINGLE_SS_ENABLE {1} \
CONFIG.PCW_QSPI_GRP_SS1_ENABLE {0} \
CONFIG.PCW_QSPI_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_SD0_GRP_CD_ENABLE {1} \
CONFIG.PCW_SD0_GRP_CD_IO {MIO 46} \
CONFIG.PCW_SD0_GRP_WP_ENABLE {0} \
CONFIG.PCW_SD0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_SD1_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_SD1_SD1_IO {MIO 10 .. 15} \
CONFIG.PCW_SDIO_PERIPHERAL_FREQMHZ {50} \
CONFIG.PCW_S_AXI_HP3_DATA_WIDTH {64} \
CONFIG.PCW_TTC0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_UART0_PERIPHERAL_ENABLE {0} \
CONFIG.PCW_UART1_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY0 {0.24} \
CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY1 {0.238} \
CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY2 {0.283} \
CONFIG.PCW_UIPARAM_DDR_BOARD_DELAY3 {0.284} \
CONFIG.PCW_UIPARAM_DDR_DQS_TO_CLK_DELAY_0 {-0.036} \
CONFIG.PCW_UIPARAM_DDR_DQS_TO_CLK_DELAY_1 {-0.036} \
CONFIG.PCW_UIPARAM_DDR_DQS_TO_CLK_DELAY_2 {0.058} \
CONFIG.PCW_UIPARAM_DDR_DQS_TO_CLK_DELAY_3 {0.057} \
CONFIG.PCW_UIPARAM_DDR_MEMORY_TYPE {DDR 3 (Low Voltage)} \
CONFIG.PCW_UIPARAM_DDR_PARTNO {MT41K256M16 RE-125} \
CONFIG.PCW_UIPARAM_DDR_TRAIN_DATA_EYE {1} \
CONFIG.PCW_UIPARAM_DDR_TRAIN_READ_GATE {0} \
CONFIG.PCW_UIPARAM_DDR_USE_INTERNAL_VREF {1} \
CONFIG.PCW_USB0_PERIPHERAL_ENABLE {1} \
CONFIG.PCW_USB0_RESET_ENABLE {1} \
CONFIG.PCW_USB0_RESET_IO {MIO 7} \
CONFIG.PCW_USE_FABRIC_INTERRUPT {1} \
CONFIG.PCW_USE_M_AXI_GP1 {0} \
CONFIG.PCW_USE_S_AXI_GP0 {0} \
CONFIG.PCW_USE_S_AXI_GP1 {0} \
CONFIG.PCW_USE_S_AXI_HP0 {1} \
CONFIG.PCW_USE_S_AXI_HP1 {1} \
CONFIG.PCW_USE_S_AXI_HP2 {1} \
CONFIG.PCW_USE_S_AXI_HP3 {1} \
CONFIG.PCW_WDT_PERIPHERAL_ENABLE {1} \
 ] $ps7

  # Create instance: xlconcat, and set properties
  set xlconcat [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat:2.1 xlconcat ]
  set_property -dict [ list \
CONFIG.NUM_PORTS {5} \
 ] $xlconcat

  # Create instance: xlconcat_1, and set properties
  set xlconcat_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat:2.1 xlconcat_1 ]
  set_property -dict [ list \
CONFIG.IN0_WIDTH {2} \
CONFIG.IN1_WIDTH {2} \
CONFIG.IN2_WIDTH {2} \
CONFIG.IN3_WIDTH {2} \
CONFIG.NUM_PORTS {2} \
 ] $xlconcat_1

  # Create instance: xlconcat_2, and set properties
  set xlconcat_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat:2.1 xlconcat_2 ]
  set_property -dict [ list \
CONFIG.IN0_WIDTH {1} \
CONFIG.IN1_WIDTH {1} \
CONFIG.NUM_PORTS {2} \
 ] $xlconcat_2

  # Create instance: xlconcat_4, and set properties
  set xlconcat_4 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat:2.1 xlconcat_4 ]

  # Create instance: xlconcat_5, and set properties
  set xlconcat_5 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconcat:2.1 xlconcat_5 ]
  set_property -dict [ list \
CONFIG.NUM_PORTS {8} \
 ] $xlconcat_5

  # Create instance: xlconstant_2, and set properties
  set xlconstant_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant:1.1 xlconstant_2 ]
  set_property -dict [ list \
CONFIG.CONST_VAL {0} \
CONFIG.CONST_WIDTH {1} \
 ] $xlconstant_2

  # Create instance: xlconstant_3, and set properties
  set xlconstant_3 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant:1.1 xlconstant_3 ]
  set_property -dict [ list \
CONFIG.CONST_VAL {0} \
CONFIG.CONST_WIDTH {1} \
 ] $xlconstant_3

  # Create instance: xlconstant_4, and set properties
  set xlconstant_4 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant:1.1 xlconstant_4 ]
  set_property -dict [ list \
CONFIG.CONST_VAL {0} \
CONFIG.CONST_WIDTH {2} \
 ] $xlconstant_4

  # Create instance: xlconstant_5, and set properties
  set xlconstant_5 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant:1.1 xlconstant_5 ]
  set_property -dict [ list \
CONFIG.CONST_VAL {0} \
 ] $xlconstant_5

  # Create instance: xlconstant_7, and set properties
  set xlconstant_7 [ create_bd_cell -type ip -vlnv xilinx.com:ip:xlconstant:1.1 xlconstant_7 ]
  set_property -dict [ list \
CONFIG.CONST_VAL {0} \
 ] $xlconstant_7

  # Create interface connections
  connect_bd_intf_net -intf_net Conn [get_bd_intf_pins lmb_bram_if_cntlr_0/SLMB] [get_bd_intf_pins lmb_v10_0/LMB_Sl_0]
  connect_bd_intf_net -intf_net Conn1 [get_bd_intf_pins lmb_bram_if_cntlr_1/SLMB] [get_bd_intf_pins lmb_v10_1/LMB_Sl_0]
  connect_bd_intf_net -intf_net S00_AXI_2 [get_bd_intf_pins axi4_lite/S00_AXI] [get_bd_intf_pins ps7/M_AXI_GP0]
  connect_bd_intf_net -intf_net S_AXI_HP3_1 [get_bd_intf_ports S_AXI_HP3] [get_bd_intf_pins ps7/S_AXI_HP3]
  connect_bd_intf_net -intf_net TGIGE0_DDR_RW_1 [get_bd_intf_ports TGIGE0_DDR_RW] [get_bd_intf_pins axi_clock_converter_3/S_AXI]
  connect_bd_intf_net -intf_net axi4_lite_M00_AXI [get_bd_intf_pins axi4_lite/M00_AXI] [get_bd_intf_pins logicvc_0/s_axi]
  connect_bd_intf_net -intf_net axi4_lite_M01_AXI [get_bd_intf_pins axi4_lite/M01_AXI] [get_bd_intf_pins logiwin_1/s_axi]
  connect_bd_intf_net -intf_net axi4_lite_M02_AXI [get_bd_intf_pins axi4_lite/M02_AXI] [get_bd_intf_pins axi_ahblite_bridge_0/AXI4]
  connect_bd_intf_net -intf_net axi_ahblite_bridge_0_M_AHB [get_bd_intf_ports M_AHB] [get_bd_intf_pins axi_ahblite_bridge_0/M_AHB]
  connect_bd_intf_net -intf_net axi_bram_ctrl_0_BRAM_PORTA [get_bd_intf_ports TGIGE0_BRAM_PORTA_0] [get_bd_intf_pins axi_bram_ctrl_0/BRAM_PORTA]
  connect_bd_intf_net -intf_net axi_bram_ctrl_1_BRAM_PORTA [get_bd_intf_ports TGIGE0_BRAM_PORTA_1] [get_bd_intf_pins axi_bram_ctrl_1/BRAM_PORTA]
  connect_bd_intf_net -intf_net axi_bram_ctrl_2_BRAM_PORTA [get_bd_intf_ports TGIGE0_BRAM_PORTA_2] [get_bd_intf_pins axi_bram_ctrl_2/BRAM_PORTA]
  connect_bd_intf_net -intf_net axi_bram_ctrl_3_BRAM_PORTA [get_bd_intf_ports TGIGE0_BRAM_PORTA_3] [get_bd_intf_pins axi_bram_ctrl_3/BRAM_PORTA]
  connect_bd_intf_net -intf_net axi_bram_ctrl_4_BRAM_PORTA [get_bd_intf_ports TGIGE0_BRAM_PORTA_4] [get_bd_intf_pins axi_bram_ctrl_4/BRAM_PORTA]
  connect_bd_intf_net -intf_net axi_bram_ctrl_5_BRAM_PORTA [get_bd_intf_ports TGIGE0_BRAM_PORTA_5] [get_bd_intf_pins axi_bram_ctrl_5/BRAM_PORTA]
  connect_bd_intf_net -intf_net axi_clock_converter_0_M_AXI [get_bd_intf_pins axi_clock_converter_0/M_AXI] [get_bd_intf_pins axi_interconnect_0/S02_AXI]
  connect_bd_intf_net -intf_net axi_clock_converter_1_M_AXI [get_bd_intf_pins axi_clock_converter_1/M_AXI] [get_bd_intf_pins axi_interconnect_0/S03_AXI]
  connect_bd_intf_net -intf_net axi_clock_converter_3_M_AXI [get_bd_intf_pins axi_clock_converter_3/M_AXI] [get_bd_intf_pins axi_interconnect_0/S00_AXI]
  connect_bd_intf_net -intf_net axi_intc_0_interrupt [get_bd_intf_pins axi_intc_0/interrupt] [get_bd_intf_pins microblaze_0/INTERRUPT]
  connect_bd_intf_net -intf_net axi_interconnect_0_M00_AXI [get_bd_intf_pins axi_interconnect_0/M00_AXI] [get_bd_intf_pins ps7/S_AXI_HP0]
  connect_bd_intf_net -intf_net axi_interconnect_1_M00_AXI [get_bd_intf_pins axi_bram_ctrl_0/S_AXI] [get_bd_intf_pins axi_interconnect_4/M00_AXI]
  connect_bd_intf_net -intf_net axi_interconnect_1_M01_AXI [get_bd_intf_pins axi_bram_ctrl_1/S_AXI] [get_bd_intf_pins axi_interconnect_4/M01_AXI]
  connect_bd_intf_net -intf_net axi_interconnect_1_M02_AXI [get_bd_intf_pins axi_bram_ctrl_2/S_AXI] [get_bd_intf_pins axi_interconnect_4/M02_AXI]
  connect_bd_intf_net -intf_net axi_interconnect_1_M03_AXI [get_bd_intf_pins axi_bram_ctrl_3/S_AXI] [get_bd_intf_pins axi_interconnect_4/M03_AXI]
  connect_bd_intf_net -intf_net axi_interconnect_1_M04_AXI [get_bd_intf_pins axi_bram_ctrl_4/S_AXI] [get_bd_intf_pins axi_interconnect_4/M04_AXI]
  connect_bd_intf_net -intf_net axi_interconnect_1_M05_AXI [get_bd_intf_pins axi_bram_ctrl_5/S_AXI] [get_bd_intf_pins axi_interconnect_4/M05_AXI]
  connect_bd_intf_net -intf_net axi_interconnect_1_M06_AXI [get_bd_intf_pins axi_interconnect_4/M06_AXI] [get_bd_intf_pins axi_timer_0/S_AXI]
  connect_bd_intf_net -intf_net axi_interconnect_1_M08_AXI [get_bd_intf_ports axi4lite_ext_slave_conn_0] [get_bd_intf_pins axi_interconnect_4/M08_AXI]
  connect_bd_intf_net -intf_net axi_interconnect_2_M00_AXI [get_bd_intf_pins axi_interconnect_2/M00_AXI] [get_bd_intf_pins ps7/S_AXI_HP2]
  connect_bd_intf_net -intf_net axi_interconnect_4_M07_AXI [get_bd_intf_pins axi_intc_0/s_axi] [get_bd_intf_pins axi_interconnect_4/M07_AXI]
  connect_bd_intf_net -intf_net lmb_bram_if_cntlr_0_BRAM_PORT [get_bd_intf_pins blk_mem_gen_0/BRAM_PORTA] [get_bd_intf_pins lmb_bram_if_cntlr_0/BRAM_PORT]
  connect_bd_intf_net -intf_net lmb_bram_if_cntlr_1_BRAM_PORT [get_bd_intf_pins blk_mem_gen_0/BRAM_PORTB] [get_bd_intf_pins lmb_bram_if_cntlr_1/BRAM_PORT]
  connect_bd_intf_net -intf_net logicvc_0_m_axi [get_bd_intf_pins axi_interconnect_2/S00_AXI] [get_bd_intf_pins logicvc_0/m_axi]
  connect_bd_intf_net -intf_net logicvc_0_vid_io [get_bd_intf_ports logicvc_0_vid_io] [get_bd_intf_pins logicvc_0/vid_io]
  connect_bd_intf_net -intf_net logiwin_1_m_axi [get_bd_intf_pins axi_interconnect_0/S01_AXI] [get_bd_intf_pins logiwin_1/m_axi]
  connect_bd_intf_net -intf_net mdm_0_MBDEBUG_0 [get_bd_intf_pins mdm_0/MBDEBUG_0] [get_bd_intf_pins microblaze_0/DEBUG]
  connect_bd_intf_net -intf_net microblaze_0_DLMB [get_bd_intf_pins lmb_v10_0/LMB_M] [get_bd_intf_pins microblaze_0/DLMB]
  connect_bd_intf_net -intf_net microblaze_0_ILMB [get_bd_intf_pins lmb_v10_1/LMB_M] [get_bd_intf_pins microblaze_0/ILMB]
  connect_bd_intf_net -intf_net microblaze_0_M_AXI_DC [get_bd_intf_pins axi_clock_converter_0/S_AXI] [get_bd_intf_pins microblaze_0/M_AXI_DC]
  connect_bd_intf_net -intf_net microblaze_0_M_AXI_DP [get_bd_intf_pins axi_interconnect_4/S00_AXI] [get_bd_intf_pins microblaze_0/M_AXI_DP]
  connect_bd_intf_net -intf_net microblaze_0_M_AXI_IC [get_bd_intf_pins axi_clock_converter_1/S_AXI] [get_bd_intf_pins microblaze_0/M_AXI_IC]
  connect_bd_intf_net -intf_net processing_system7_0_DDR [get_bd_intf_ports DDR] [get_bd_intf_pins ps7/DDR]
  connect_bd_intf_net -intf_net processing_system7_0_FIXED_IO [get_bd_intf_ports FIXED_IO] [get_bd_intf_pins ps7/FIXED_IO]
  connect_bd_intf_net -intf_net processing_system7_0_GPIO_0 [get_bd_intf_ports GPIO_0] [get_bd_intf_pins ps7/GPIO_0]

  # Create port connections
  connect_bd_net -net In0_1 [get_bd_ports TGIGE0_tx_retr_int] [get_bd_pins xlconcat_5/In0]
  connect_bd_net -net In1_1 [get_bd_ports TGIGE0_tx_gvsp_int] [get_bd_pins xlconcat_5/In1]
  connect_bd_net -net In2_1 [get_bd_ports TGIGE0_tx_gvcp_int] [get_bd_pins xlconcat_5/In2]
  connect_bd_net -net In3_1 [get_bd_ports TGIGE0_rx_norm_int] [get_bd_pins xlconcat_5/In3]
  connect_bd_net -net In4_1 [get_bd_ports TGIGE0_rx_icmp_int] [get_bd_pins xlconcat_5/In4]
  connect_bd_net -net In5_1 [get_bd_ports TGIGE0_tx_nonmac_int] [get_bd_pins xlconcat_5/In5]
  connect_bd_net -net M00_ACLK_2 [get_bd_pins axi_clock_converter_0/m_axi_aclk] [get_bd_pins axi_clock_converter_1/m_axi_aclk] [get_bd_pins axi_clock_converter_3/m_axi_aclk] [get_bd_pins axi_interconnect_0/ACLK] [get_bd_pins axi_interconnect_0/M00_ACLK] [get_bd_pins axi_interconnect_0/S00_ACLK] [get_bd_pins axi_interconnect_0/S01_ACLK] [get_bd_pins axi_interconnect_0/S02_ACLK] [get_bd_pins axi_interconnect_0/S03_ACLK] [get_bd_pins axi_interconnect_2/ACLK] [get_bd_pins axi_interconnect_2/M00_ACLK] [get_bd_pins axi_interconnect_2/S00_ACLK] [get_bd_pins clk2_reset/slowest_sync_clk] [get_bd_pins clk_wiz_0/clk_out1] [get_bd_pins logicvc_0/M_AXI_ACLK] [get_bd_pins logiwin_1/m_axi_aclk] [get_bd_pins ps7/S_AXI_HP0_ACLK] [get_bd_pins ps7/S_AXI_HP1_ACLK] [get_bd_pins ps7/S_AXI_HP2_ACLK]
  connect_bd_net -net Reset_1 [get_bd_ports MB_Reset] [get_bd_pins microblaze_0/Reset]
  connect_bd_net -net axi_timer_0_interrupt [get_bd_pins axi_timer_0/interrupt] [get_bd_pins xlconcat_5/In6]
  connect_bd_net -net clk1_reset_bus_struct_reset [get_bd_pins clk1_reset/bus_struct_reset] [get_bd_pins lmb_bram_if_cntlr_0/LMB_Rst] [get_bd_pins lmb_bram_if_cntlr_1/LMB_Rst] [get_bd_pins lmb_v10_0/SYS_Rst] [get_bd_pins lmb_v10_1/SYS_Rst] [get_bd_pins logicvc_0/rst]
  connect_bd_net -net clk1_reset_interconnect_aresetn [get_bd_pins axi4_lite/ARESETN] [get_bd_pins axi_interconnect_4/ARESETN] [get_bd_pins clk1_reset/interconnect_aresetn]
  connect_bd_net -net clk1_reset_peripheral_aresetn [get_bd_pins axi4_lite/M00_ARESETN] [get_bd_pins axi4_lite/M01_ARESETN] [get_bd_pins axi4_lite/M02_ARESETN] [get_bd_pins axi4_lite/S00_ARESETN] [get_bd_pins axi_ahblite_bridge_0/s_axi_aresetn] [get_bd_pins axi_bram_ctrl_0/s_axi_aresetn] [get_bd_pins axi_bram_ctrl_1/s_axi_aresetn] [get_bd_pins axi_bram_ctrl_2/s_axi_aresetn] [get_bd_pins axi_bram_ctrl_3/s_axi_aresetn] [get_bd_pins axi_bram_ctrl_4/s_axi_aresetn] [get_bd_pins axi_bram_ctrl_5/s_axi_aresetn] [get_bd_pins axi_clock_converter_0/s_axi_aresetn] [get_bd_pins axi_clock_converter_1/s_axi_aresetn] [get_bd_pins axi_intc_0/s_axi_aresetn] [get_bd_pins axi_interconnect_4/M00_ARESETN] [get_bd_pins axi_interconnect_4/M01_ARESETN] [get_bd_pins axi_interconnect_4/M02_ARESETN] [get_bd_pins axi_interconnect_4/M03_ARESETN] [get_bd_pins axi_interconnect_4/M04_ARESETN] [get_bd_pins axi_interconnect_4/M05_ARESETN] [get_bd_pins axi_interconnect_4/M06_ARESETN] [get_bd_pins axi_interconnect_4/M07_ARESETN] [get_bd_pins axi_interconnect_4/M08_ARESETN] [get_bd_pins axi_interconnect_4/S00_ARESETN] [get_bd_pins axi_timer_0/s_axi_aresetn] [get_bd_pins clk1_reset/peripheral_aresetn] [get_bd_pins logicvc_0/S_AXI_ARESETN] [get_bd_pins logiwin_1/s_axi_aresetn]
  connect_bd_net -net clk2_reset_interconnect_aresetn [get_bd_pins axi_interconnect_0/ARESETN] [get_bd_pins axi_interconnect_2/ARESETN] [get_bd_pins clk2_reset/interconnect_aresetn]
  connect_bd_net -net clk2_reset_peripheral_aresetn [get_bd_pins axi_clock_converter_0/m_axi_aresetn] [get_bd_pins axi_clock_converter_1/m_axi_aresetn] [get_bd_pins axi_clock_converter_3/m_axi_aresetn] [get_bd_pins axi_interconnect_0/M00_ARESETN] [get_bd_pins axi_interconnect_0/S00_ARESETN] [get_bd_pins axi_interconnect_0/S01_ARESETN] [get_bd_pins axi_interconnect_0/S02_ARESETN] [get_bd_pins axi_interconnect_0/S03_ARESETN] [get_bd_pins axi_interconnect_2/M00_ARESETN] [get_bd_pins axi_interconnect_2/S00_ARESETN] [get_bd_pins clk2_reset/peripheral_aresetn] [get_bd_pins logicvc_0/M_AXI_ARESETN] [get_bd_pins logiwin_1/m_axi_aresetn]
  connect_bd_net -net clk_wiz_0_clk_out2 [get_bd_ports CLK_25M] [get_bd_pins clk_wiz_0/clk_out2]
  connect_bd_net -net clk_wiz_0_locked [get_bd_pins clk2_reset/dcm_locked] [get_bd_pins clk_wiz_0/locked]
  connect_bd_net -net hdmi_in_2_data_1 [get_bd_ports hdmi_in_2_data] [get_bd_pins logiwin_1/vdata_in_0]
  connect_bd_net -net hdmi_in_2_vclk_1 [get_bd_ports hdmi_in_2_vclk] [get_bd_pins logiwin_1/vclk_0]
  connect_bd_net -net logicvc_0_e_next_vbuff [get_bd_pins logicvc_0/e_next_vbuff] [get_bd_pins oidsconcat_1/din]
  connect_bd_net -net logicvc_0_e_sw_grant [get_bd_pins logicvc_0/e_sw_grant] [get_bd_pins oidsconcat_0/din]
  connect_bd_net -net logicvc_0_pix_clk_o [get_bd_ports logicvc_0_pix_clk] [get_bd_pins logicvc_0/pix_clk_o]
  connect_bd_net -net logiwin_1_curr_vbuff [get_bd_pins logiwin_1/curr_vbuff] [get_bd_pins xlconcat_1/In1]
  connect_bd_net -net logiwin_1_interrupt [get_bd_pins logiwin_1/interrupt] [get_bd_pins xlconcat/In1]
  connect_bd_net -net logiwin_1_sw_vbuff_req [get_bd_pins logiwin_1/sw_vbuff_req] [get_bd_pins xlconcat_2/In1]
  connect_bd_net -net mdm_0_Debug_SYS_Rst [get_bd_pins clk1_reset/mb_debug_sys_rst] [get_bd_pins mdm_0/Debug_SYS_Rst]
  connect_bd_net -net oidsconcat_0_Out1 [get_bd_pins logiwin_1/sw_vbuff_grant] [get_bd_pins oidsconcat_0/Out1]
  connect_bd_net -net oidsconcat_1_Out2 [get_bd_pins oidsconcat_1/Out2] [get_bd_pins xlconcat_4/In0]
  connect_bd_net -net oidsconcat_1_Out3 [get_bd_pins oidsconcat_1/Out3] [get_bd_pins xlconcat_4/In1]
  connect_bd_net -net processing_system7_0_FCLK_CLK0 [get_bd_ports CLK_100M] [get_bd_ports CLOCK_160MHz] [get_bd_pins axi4_lite/ACLK] [get_bd_pins axi4_lite/M00_ACLK] [get_bd_pins axi4_lite/M01_ACLK] [get_bd_pins axi4_lite/M02_ACLK] [get_bd_pins axi4_lite/S00_ACLK] [get_bd_pins axi_ahblite_bridge_0/s_axi_aclk] [get_bd_pins axi_bram_ctrl_0/s_axi_aclk] [get_bd_pins axi_bram_ctrl_1/s_axi_aclk] [get_bd_pins axi_bram_ctrl_2/s_axi_aclk] [get_bd_pins axi_bram_ctrl_3/s_axi_aclk] [get_bd_pins axi_bram_ctrl_4/s_axi_aclk] [get_bd_pins axi_bram_ctrl_5/s_axi_aclk] [get_bd_pins axi_clock_converter_0/s_axi_aclk] [get_bd_pins axi_clock_converter_1/s_axi_aclk] [get_bd_pins axi_intc_0/s_axi_aclk] [get_bd_pins axi_interconnect_4/ACLK] [get_bd_pins axi_interconnect_4/M00_ACLK] [get_bd_pins axi_interconnect_4/M01_ACLK] [get_bd_pins axi_interconnect_4/M02_ACLK] [get_bd_pins axi_interconnect_4/M03_ACLK] [get_bd_pins axi_interconnect_4/M04_ACLK] [get_bd_pins axi_interconnect_4/M05_ACLK] [get_bd_pins axi_interconnect_4/M06_ACLK] [get_bd_pins axi_interconnect_4/M07_ACLK] [get_bd_pins axi_interconnect_4/M08_ACLK] [get_bd_pins axi_interconnect_4/S00_ACLK] [get_bd_pins axi_timer_0/s_axi_aclk] [get_bd_pins clk1_reset/slowest_sync_clk] [get_bd_pins clk_wiz_0/clk_in1] [get_bd_pins lmb_bram_if_cntlr_0/LMB_Clk] [get_bd_pins lmb_bram_if_cntlr_1/LMB_Clk] [get_bd_pins lmb_v10_0/LMB_Clk] [get_bd_pins lmb_v10_1/LMB_Clk] [get_bd_pins logicvc_0/S_AXI_ACLK] [get_bd_pins logiwin_1/s_axi_aclk] [get_bd_pins microblaze_0/Clk] [get_bd_pins ps7/FCLK_CLK0] [get_bd_pins ps7/M_AXI_GP0_ACLK] [get_bd_pins ps7/S_AXI_HP3_ACLK]
  connect_bd_net -net processing_system7_0_FCLK_CLK1 [get_bd_pins proc_sys_reset_1/slowest_sync_clk] [get_bd_pins ps7/FCLK_CLK1]
  connect_bd_net -net processing_system7_0_FCLK_CLK2 [get_bd_ports CLK_125M] [get_bd_pins ps7/FCLK_CLK2]
  connect_bd_net -net processing_system7_0_FCLK_CLK3 [get_bd_ports CLK_200M] [get_bd_pins ps7/FCLK_CLK3]
  connect_bd_net -net processing_system7_0_FCLK_RESET0_N [get_bd_pins axi_clock_converter_3/s_axi_aresetn] [get_bd_pins clk1_reset/ext_reset_in] [get_bd_pins clk2_reset/ext_reset_in] [get_bd_pins clk_wiz_0/resetn] [get_bd_pins proc_sys_reset_1/ext_reset_in] [get_bd_pins ps7/FCLK_RESET0_N]
  connect_bd_net -net processing_system7_0_FCLK_RESET1_N [get_bd_ports FCLK_RESET1_N] [get_bd_pins ps7/FCLK_RESET1_N]
  connect_bd_net -net vdata_in_de_0_1 [get_bd_ports vdata_in_de_0] [get_bd_pins logiwin_1/vdata_in_de_0]
  connect_bd_net -net vdata_in_fld_0_1 [get_bd_ports vdata_in_fld_0] [get_bd_pins logiwin_1/vdata_in_fld_0]
  connect_bd_net -net vdata_in_hs_0_1 [get_bd_ports vdata_in_hs_0] [get_bd_pins logiwin_1/vdata_in_hs_0]
  connect_bd_net -net vdata_in_vs_0_1 [get_bd_ports vdata_in_vs_0] [get_bd_pins logiwin_1/vdata_in_vs_0]
  connect_bd_net -net video_clk_in_1 [get_bd_ports video_clk] [get_bd_pins axi_clock_converter_3/s_axi_aclk] [get_bd_pins logicvc_0/vclk]
  connect_bd_net -net xlconcat_0_dout [get_bd_pins ps7/IRQ_F2P] [get_bd_pins xlconcat/dout]
  connect_bd_net -net xlconcat_1_dout [get_bd_pins logicvc_0/e_curr_vbuff] [get_bd_pins xlconcat_1/dout]
  connect_bd_net -net xlconcat_2_dout [get_bd_pins logicvc_0/e_sw_vbuff] [get_bd_pins xlconcat_2/dout]
  connect_bd_net -net xlconcat_4_dout [get_bd_pins logiwin_1/next_vbuff] [get_bd_pins xlconcat_4/dout]
  connect_bd_net -net xlconcat_5_dout [get_bd_pins axi_intc_0/intr] [get_bd_pins xlconcat_5/dout]
  connect_bd_net -net xlconstant_2_dout [get_bd_pins logiwin_1/rst_regs] [get_bd_pins xlconstant_2/dout]
  connect_bd_net -net xlconstant_3_dout [get_bd_pins logiwin_1/capture_stop] [get_bd_pins xlconcat/In0] [get_bd_pins xlconcat/In2] [get_bd_pins xlconcat/In3] [get_bd_pins xlconstant_3/dout]
  connect_bd_net -net xlconstant_4_dout [get_bd_pins xlconcat_1/In0] [get_bd_pins xlconstant_4/dout]
  connect_bd_net -net xlconstant_5_dout [get_bd_pins xlconcat_2/In0] [get_bd_pins xlconstant_5/dout]
  connect_bd_net -net xlconstant_7_dout [get_bd_pins xlconcat_5/In7] [get_bd_pins xlconstant_7/dout]

  # Create address segments
  create_bd_addr_seg -range 0x40000000 -offset 0x0 [get_bd_addr_spaces logicvc_0/videoData] [get_bd_addr_segs ps7/S_AXI_HP2/HP2_DDR_LOWOCM] SEG_processing_system7_0_HP2_DDR_LOWOCM
  create_bd_addr_seg -range 0x2000000 -offset 0x34000000 [get_bd_addr_spaces logiwin_1/winData] [get_bd_addr_segs ps7/S_AXI_HP0/HP0_DDR_LOWOCM] SEG_processing_system7_0_HP0_DDR_LOWOCM
  create_bd_addr_seg -range 0x10000 -offset 0x10500000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs axi4lite_ext_slave_conn_0/Reg] SEG_axi4lite_ext_slave_conn_0_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x10000000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs axi_bram_ctrl_0/S_AXI/Mem0] SEG_axi_bram_ctrl_0_Mem0
  create_bd_addr_seg -range 0x10000 -offset 0x10100000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs axi_bram_ctrl_1/S_AXI/Mem0] SEG_axi_bram_ctrl_1_Mem0
  create_bd_addr_seg -range 0x10000 -offset 0x10200000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs axi_bram_ctrl_2/S_AXI/Mem0] SEG_axi_bram_ctrl_2_Mem0
  create_bd_addr_seg -range 0x20000 -offset 0x10300000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs axi_bram_ctrl_3/S_AXI/Mem0] SEG_axi_bram_ctrl_3_Mem0
  create_bd_addr_seg -range 0x20000 -offset 0x10400000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs axi_bram_ctrl_4/S_AXI/Mem0] SEG_axi_bram_ctrl_4_Mem0
  create_bd_addr_seg -range 0x10000 -offset 0x20000000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs axi_bram_ctrl_5/S_AXI/Mem0] SEG_axi_bram_ctrl_5_Mem0
  create_bd_addr_seg -range 0x10000 -offset 0x70000000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs axi_intc_0/s_axi/Reg] SEG_axi_intc_0_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x70100000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs axi_timer_0/S_AXI/Reg] SEG_axi_timer_0_Reg
  create_bd_addr_seg -range 0x4000 -offset 0x0 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs lmb_bram_if_cntlr_0/SLMB/Mem] SEG_lmb_bram_if_cntlr_0_Mem
  create_bd_addr_seg -range 0x4000 -offset 0x0 [get_bd_addr_spaces microblaze_0/Instruction] [get_bd_addr_segs lmb_bram_if_cntlr_1/SLMB/Mem] SEG_lmb_bram_if_cntlr_1_Mem
  create_bd_addr_seg -range 0x8000000 -offset 0x38000000 [get_bd_addr_spaces microblaze_0/Data] [get_bd_addr_segs ps7/S_AXI_HP0/HP0_DDR_LOWOCM] SEG_ps7_HP0_DDR_LOWOCM
  create_bd_addr_seg -range 0x8000000 -offset 0x38000000 [get_bd_addr_spaces microblaze_0/Instruction] [get_bd_addr_segs ps7/S_AXI_HP0/HP0_DDR_LOWOCM] SEG_ps7_HP0_DDR_LOWOCM
  create_bd_addr_seg -range 0x10000 -offset 0x43C20000 [get_bd_addr_spaces ps7/Data] [get_bd_addr_segs M_AHB/Reg] SEG_M_AHB_Reg
  create_bd_addr_seg -range 0x10000 -offset 0x43C00000 [get_bd_addr_spaces ps7/Data] [get_bd_addr_segs logicvc_0/s_axi/reg0] SEG_logicvc_0_reg0
  create_bd_addr_seg -range 0x10000 -offset 0x43C30000 [get_bd_addr_spaces ps7/Data] [get_bd_addr_segs logiwin_1/s_axi/reg0] SEG_logiwin_1_reg0
  create_bd_addr_seg -range 0x40000000 -offset 0x0 [get_bd_addr_spaces S_AXI_HP3] [get_bd_addr_segs ps7/S_AXI_HP3/HP3_DDR_LOWOCM] SEG_processing_system7_0_HP3_DDR_LOWOCM
  create_bd_addr_seg -range 0x40000000 -offset 0x0 [get_bd_addr_spaces TGIGE0_DDR_RW] [get_bd_addr_segs ps7/S_AXI_HP0/HP0_DDR_LOWOCM] SEG_ps7_HP0_DDR_LOWOCM

  # Perform GUI Layout
  regenerate_bd_layout -layout_string {
   guistr: "# # String gsaved with Nlview 6.5.5  2015-06-26 bk=1.3371 VDI=38 GEI=35 GUI=JA:1.6
#  -string -flagsOSRD
preplace port video_clk -pg 1 -y 2340 -defaultsOSRD
preplace port logicvc_0_vid_io -pg 1 -y 1650 -defaultsOSRD
preplace port DDR -pg 1 -y 60 -defaultsOSRD
preplace port CLK_25M -pg 1 -y 1580 -defaultsOSRD
preplace port vdata_in_vs_0 -pg 1 -y 2200 -defaultsOSRD
preplace port CLK_100M -pg 1 -y 1480 -defaultsOSRD
preplace port TGIGE0_DDR_RW -pg 1 -y 400 -defaultsOSRD
preplace port S_AXI_HP3 -pg 1 -y 190 -defaultsOSRD
preplace port vdata_in_hs_0 -pg 1 -y 2180 -defaultsOSRD
preplace port hdmi_in_2_vclk -pg 1 -y 2120 -defaultsOSRD
preplace port MB_Reset -pg 1 -y 520 -defaultsOSRD
preplace port TGIGE0_BRAM_PORTA_0 -pg 1 -y 660 -defaultsOSRD
preplace port TGIGE0_BRAM_PORTA_1 -pg 1 -y 800 -defaultsOSRD
preplace port M_AHB -pg 1 -y 1430 -defaultsOSRD
preplace port GPIO_0 -pg 1 -y 40 -defaultsOSRD
preplace port CLK_125M -pg 1 -y 260 -defaultsOSRD
preplace port CLOCK_160MHz -pg 1 -y 1500 -defaultsOSRD
preplace port TGIGE0_BRAM_PORTA_2 -pg 1 -y 920 -defaultsOSRD
preplace port vdata_in_fld_0 -pg 1 -y 2220 -defaultsOSRD
preplace port FCLK_RESET1_N -pg 1 -y 460 -defaultsOSRD
preplace port CLK_200M -pg 1 -y 280 -defaultsOSRD
preplace port logicvc_0_pix_clk -pg 1 -y 1670 -defaultsOSRD
preplace port TGIGE0_BRAM_PORTA_3 -pg 1 -y 1040 -defaultsOSRD
preplace port vdata_in_de_0 -pg 1 -y 2160 -defaultsOSRD
preplace port TGIGE0_BRAM_PORTA_4 -pg 1 -y 1160 -defaultsOSRD
preplace port FIXED_IO -pg 1 -y 80 -defaultsOSRD
preplace port axi4lite_ext_slave_conn_0 -pg 1 -y 730 -defaultsOSRD
preplace port TGIGE0_BRAM_PORTA_5 -pg 1 -y 1280 -defaultsOSRD
preplace portBus TGIGE0_rx_icmp_int -pg 1 -y 1270 -defaultsOSRD
preplace portBus hdmi_in_2_data -pg 1 -y 2140 -defaultsOSRD
preplace portBus TGIGE0_tx_nonmac_int -pg 1 -y 1290 -defaultsOSRD
preplace portBus TGIGE0_tx_retr_int -pg 1 -y 1190 -defaultsOSRD
preplace portBus TGIGE0_tx_gvcp_int -pg 1 -y 1230 -defaultsOSRD
preplace portBus TGIGE0_tx_gvsp_int -pg 1 -y 1210 -defaultsOSRD
preplace portBus TGIGE0_rx_norm_int -pg 1 -y 1250 -defaultsOSRD
preplace inst logicvc_0 -pg 1 -lvl 4 -y 1700 -defaultsOSRD
preplace inst axi_interconnect_4 -pg 1 -lvl 2 -y 840 -defaultsOSRD
preplace inst axi_bram_ctrl_2 -pg 1 -lvl 6 -y 920 -defaultsOSRD
preplace inst axi4_lite -pg 1 -lvl 3 -y 1470 -defaultsOSRD
preplace inst axi_clock_converter_0 -pg 1 -lvl 4 -y 600 -defaultsOSRD
preplace inst axi_bram_ctrl_3 -pg 1 -lvl 6 -y 1040 -defaultsOSRD
preplace inst axi_clock_converter_1 -pg 1 -lvl 4 -y 760 -defaultsOSRD -resize 240 140
preplace inst axi_intc_0 -pg 1 -lvl 3 -y 1250 -defaultsOSRD
preplace inst oidsconcat_0 -pg 1 -lvl 3 -y 2530 -defaultsOSRD
preplace inst axi_bram_ctrl_4 -pg 1 -lvl 6 -y 1160 -defaultsOSRD
preplace inst ps7 -pg 1 -lvl 6 -y 180 -defaultsOSRD
preplace inst oidsconcat_1 -pg 1 -lvl 2 -y 1840 -defaultsOSRD
preplace inst axi_bram_ctrl_5 -pg 1 -lvl 6 -y 1280 -defaultsOSRD
preplace inst axi_clock_converter_3 -pg 1 -lvl 1 -y 500 -defaultsOSRD -resize 240 140
preplace inst xlconstant_2 -pg 1 -lvl 3 -y 2920 -defaultsOSRD
preplace inst xlconstant_3 -pg 1 -lvl 3 -y 3100 -defaultsOSRD
preplace inst axi_timer_0 -pg 1 -lvl 3 -y 1050 -defaultsOSRD
preplace inst xlconstant_4 -pg 1 -lvl 2 -y 2430 -defaultsOSRD
preplace inst xlconcat_1 -pg 1 -lvl 3 -y 3010 -defaultsOSRD
preplace inst proc_sys_reset_1 -pg 1 -lvl 7 -y 370 -defaultsOSRD
preplace inst mdm_0 -pg 1 -lvl 3 -y 880 -defaultsOSRD
preplace inst clk2_reset -pg 1 -lvl 3 -y 1750 -defaultsOSRD
preplace inst clk1_reset -pg 1 -lvl 1 -y 1410 -defaultsOSRD
preplace inst blk_mem_gen_0 -pg 1 -lvl 7 -y 530 -defaultsOSRD
preplace inst axi_ahblite_bridge_0 -pg 1 -lvl 6 -y 1430 -defaultsOSRD
preplace inst xlconstant_5 -pg 1 -lvl 2 -y 2010 -defaultsOSRD
preplace inst xlconcat_2 -pg 1 -lvl 3 -y 2030 -defaultsOSRD
preplace inst xlconcat -pg 1 -lvl 5 -y 2270 -defaultsOSRD
preplace inst logiwin_1 -pg 1 -lvl 4 -y 2220 -defaultsOSRD
preplace inst xlconstant_7 -pg 1 -lvl 1 -y 1530 -defaultsOSRD
preplace inst xlconcat_4 -pg 1 -lvl 3 -y 1880 -defaultsOSRD
preplace inst microblaze_0 -pg 1 -lvl 4 -y 360 -defaultsOSRD
preplace inst axi_interconnect_0 -pg 1 -lvl 5 -y 550 -defaultsOSRD
preplace inst xlconcat_5 -pg 1 -lvl 2 -y 1260 -defaultsOSRD
preplace inst lmb_v10_0 -pg 1 -lvl 5 -y 900 -defaultsOSRD
preplace inst lmb_bram_if_cntlr_0 -pg 1 -lvl 6 -y 420 -defaultsOSRD
preplace inst clk_wiz_0 -pg 1 -lvl 6 -y 1580 -defaultsOSRD
preplace inst lmb_v10_1 -pg 1 -lvl 5 -y 270 -defaultsOSRD
preplace inst lmb_bram_if_cntlr_1 -pg 1 -lvl 6 -y 540 -defaultsOSRD
preplace inst axi_interconnect_2 -pg 1 -lvl 5 -y 1100 -defaultsOSRD
preplace inst axi_bram_ctrl_0 -pg 1 -lvl 6 -y 660 -defaultsOSRD
preplace inst axi_bram_ctrl_1 -pg 1 -lvl 6 -y 800 -defaultsOSRD
preplace netloc axi_clock_converter_3_M_AXI 1 1 4 NJ 450 NJ 450 NJ 450 2020
preplace netloc S00_AXI_2 1 2 5 960 790 NJ 850 NJ 790 NJ 1350 3050
preplace netloc xlconstant_4_dout 1 2 1 NJ
preplace netloc microblaze_0_DLMB 1 4 1 2120
preplace netloc logiwin_1_interrupt 1 4 1 NJ
preplace netloc axi_timer_0_interrupt 1 1 3 570 560 NJ 560 1310
preplace netloc axi_interconnect_1_M03_AXI 1 2 4 NJ 800 NJ 880 NJ 800 2520
preplace netloc processing_system7_0_FIXED_IO 1 6 2 NJ 80 NJ
preplace netloc mdm_0_Debug_SYS_Rst 1 0 4 NJ 410 NJ 410 NJ 410 1320
preplace netloc xlconcat_2_dout 1 3 1 1400
preplace netloc axi4_lite_M00_AXI 1 3 1 1400
preplace netloc TGIGE0_DDR_RW_1 1 0 1 40
preplace netloc axi_clock_converter_0_M_AXI 1 4 1 2030
preplace netloc xlconstant_3_dout 1 3 2 1450 2010 NJ
preplace netloc lmb_bram_if_cntlr_1_BRAM_PORT 1 6 1 N
preplace netloc xlconcat_1_dout 1 3 1 1440
preplace netloc microblaze_0_M_AXI_IC 1 3 2 1460 470 2010
preplace netloc In2_1 1 0 2 NJ 1230 NJ
preplace netloc axi_bram_ctrl_1_BRAM_PORTA 1 6 2 NJ 800 NJ
preplace netloc xlconcat_0_dout 1 5 1 2600
preplace netloc vdata_in_vs_0_1 1 0 4 NJ 2200 NJ 2200 NJ 2200 NJ
preplace netloc clk1_reset_interconnect_aresetn 1 1 2 530 1410 N
preplace netloc processing_system7_0_GPIO_0 1 6 2 NJ 40 NJ
preplace netloc microblaze_0_M_AXI_DP 1 1 4 560 250 NJ 250 NJ 250 2020
preplace netloc logiwin_1_m_axi 1 4 1 2080
preplace netloc processing_system7_0_FCLK_RESET1_N 1 6 2 NJ 280 NJ
preplace netloc processing_system7_0_DDR 1 6 2 NJ 60 NJ
preplace netloc clk2_reset_peripheral_aresetn 1 0 5 70 400 NJ 400 NJ 400 1390 500 2050
preplace netloc xlconstant_5_dout 1 2 1 NJ
preplace netloc logicvc_0_vid_io 1 4 4 NJ 1650 NJ 1650 NJ 1650 NJ
preplace netloc axi4_lite_M01_AXI 1 3 1 1360
preplace netloc axi_interconnect_1_M00_AXI 1 2 4 950 460 NJ 460 NJ 760 NJ
preplace netloc axi_interconnect_1_M05_AXI 1 2 4 NJ 820 NJ 870 NJ 820 2540
preplace netloc axi_interconnect_1_M04_AXI 1 2 4 NJ 810 NJ 860 NJ 830 2530
preplace netloc clk2_reset_interconnect_aresetn 1 3 2 NJ 1080 2150
preplace netloc processing_system7_0_FCLK_RESET0_N 1 0 7 NJ 1320 NJ 1420 880 1660 NJ 1830 NJ 1590 2630 730 3060
preplace netloc logiwin_1_curr_vbuff 1 2 3 960 2110 NJ 2030 2010
preplace netloc axi_interconnect_1_M08_AXI 1 2 6 NJ 940 NJ 940 NJ 810 NJ 1360 NJ 1360 NJ
preplace netloc axi_bram_ctrl_0_BRAM_PORTA 1 6 2 NJ 660 NJ
preplace netloc xlconcat_4_dout 1 3 1 1330
preplace netloc vdata_in_fld_0_1 1 0 4 NJ 2190 NJ 2190 NJ 2190 NJ
preplace netloc logiwin_1_sw_vbuff_req 1 2 3 960 1970 NJ 1970 2020
preplace netloc axi_bram_ctrl_5_BRAM_PORTA 1 6 2 NJ 1280 NJ
preplace netloc axi4_lite_M02_AXI 1 3 3 1350 1410 NJ 1410 NJ
preplace netloc mdm_0_MBDEBUG_0 1 3 1 1340
preplace netloc In1_1 1 0 2 NJ 1210 NJ
preplace netloc video_clk_in_1 1 0 4 NJ 1650 NJ 1650 NJ 1650 1370
preplace netloc axi_clock_converter_1_M_AXI 1 4 1 2040
preplace netloc clk1_reset_bus_struct_reset 1 1 5 NJ 1140 NJ 1150 1460 920 2070 340 2640
preplace netloc Conn 1 5 1 2580
preplace netloc lmb_bram_if_cntlr_0_BRAM_PORT 1 6 1 3070
preplace netloc axi_interconnect_1_M02_AXI 1 2 4 NJ 950 NJ 950 NJ 970 2620
preplace netloc xlconstant_2_dout 1 3 1 NJ
preplace netloc axi_bram_ctrl_4_BRAM_PORTA 1 6 2 NJ 1160 NJ
preplace netloc Reset_1 1 0 4 NJ 390 NJ 390 NJ 390 NJ
preplace netloc axi_interconnect_1_M06_AXI 1 2 1 910
preplace netloc In3_1 1 0 2 NJ 1250 NJ
preplace netloc vdata_in_hs_0_1 1 0 4 NJ 2160 NJ 2160 NJ 2160 NJ
preplace netloc oidsconcat_0_Out1 1 3 1 1460
preplace netloc microblaze_0_ILMB 1 4 1 2030
preplace netloc processing_system7_0_FCLK_CLK0 1 0 8 90 1120 NJ 1120 910 1170 NJ 260 NJ 200 2550 1500 3080 1480 NJ
preplace netloc axi_bram_ctrl_3_BRAM_PORTA 1 6 2 NJ 1040 NJ
preplace netloc logicvc_0_pix_clk_o 1 4 4 NJ 1670 NJ 1670 NJ 1670 NJ
preplace netloc processing_system7_0_FCLK_CLK1 1 6 1 3090
preplace netloc axi_interconnect_4_M07_AXI 1 2 1 890
preplace netloc processing_system7_0_FCLK_CLK2 1 6 2 NJ 250 NJ
preplace netloc logicvc_0_e_sw_grant 1 2 3 940 1960 NJ 1960 2010
preplace netloc axi_interconnect_2_M00_AXI 1 5 1 2560
preplace netloc oidsconcat_1_Out2 1 2 1 940
preplace netloc oidsconcat_1_Out3 1 2 1 900
preplace netloc axi_interconnect_1_M01_AXI 1 2 4 NJ 480 NJ 480 NJ 780 NJ
preplace netloc clk_wiz_0_locked 1 2 5 960 1940 NJ 1940 NJ 1940 NJ 1940 3050
preplace netloc processing_system7_0_FCLK_CLK3 1 6 2 NJ 270 NJ
preplace netloc In5_1 1 0 2 NJ 1290 NJ
preplace netloc axi_bram_ctrl_2_BRAM_PORTA 1 6 2 NJ 920 NJ
preplace netloc clk1_reset_peripheral_aresetn 1 1 5 560 1380 940 1160 1410 510 2100 770 2640
preplace netloc hdmi_in_2_data_1 1 0 4 NJ 2120 NJ 2120 NJ 2120 NJ
preplace netloc Conn1 1 5 1 2590
preplace netloc axi_ahblite_bridge_0_M_AHB 1 6 2 NJ 1430 NJ
preplace netloc In4_1 1 0 2 NJ 1270 NJ
preplace netloc logicvc_0_e_next_vbuff 1 1 4 550 1950 NJ 1950 NJ 1950 2030
preplace netloc vdata_in_de_0_1 1 0 4 NJ 2140 NJ 2140 NJ 2140 NJ
preplace netloc clk_wiz_0_clk_out2 1 6 2 NJ 1580 NJ
preplace netloc logicvc_0_m_axi 1 4 1 2160
preplace netloc microblaze_0_M_AXI_DC 1 3 2 1450 270 2010
preplace netloc hdmi_in_2_vclk_1 1 0 4 NJ 2100 NJ 2100 NJ 2100 NJ
preplace netloc S_AXI_HP3_1 1 0 6 NJ 180 NJ 180 NJ 180 NJ 180 NJ 180 NJ
preplace netloc In0_1 1 0 2 NJ 1190 NJ
preplace netloc axi_intc_0_interrupt 1 3 1 1330
preplace netloc M00_ACLK_2 1 0 7 60 1640 NJ 1640 930 1640 1420 490 2170 980 2610 1510 3050
preplace netloc axi_interconnect_0_M00_AXI 1 5 1 2510
preplace netloc xlconstant_7_dout 1 1 1 570
preplace netloc xlconcat_5_dout 1 2 1 880
levelinfo -pg 1 0 380 740 1160 1780 2370 2850 3260 3450 -top 0 -bot 3150
",
}

  # Restore current instance
  current_bd_instance $oldCurInst

  save_bd_design
}
# End of create_root_design()


##################################################################
# MAIN FLOW
##################################################################

create_root_design ""


